
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.33'
version = '1.1.33'
full_version = '1.1.33'
git_revision = '078304b24577ab4f5c13ff9ecdefa4be525d8c35'
release = True

if not release:
    version = full_version
    short_version += ".dev"
